@@ -3,6 +3,7 @@ import itertools
 import sys
 from plotly.colors import DEFAULT_PLOTLY_COLORS as plcolors
 import gzip
+import logging
 
 
 class Transcript(object):
@@ -53,7 +54,7 @@ def parse_attributes(attributes):
     """
     info = {i.split(' ')[0]: i.split(' ')[1].replace('"', '') for i in attributes.split(
         '; ') if i.startswith('gene_name') or i.startswith('transcript_id')}
-    return info["gene_name"], info["transcript_id"]
+    return info.get("gene_name"), info.get("transcript_id")
 
 
 def transcripts_in_window(df, window, feature='transcript'):
@@ -71,23 +72,27 @@ def parse_gtf(gtff, window, simplify=False):
     Parse the gtff and select the relevant region as determined by the window
     return as Transcript objects
     """
+    logging.info("Parsing GTF file...")
     df = pd.DataFrame(data=[get_features(line)
                             for line in open_gtf(gtff) if good_record(line, window.chromosome)],
                       columns=['chromosome', 'begin', 'end', 'strand', 'gene', 'transcript'])
+    logging.info("Loaded GTF file, processing...")
     if simplify:
         df.drop_duplicates(subset=['chromosome', 'begin', 'end', 'gene'], inplace=True)
         res = []
         for g in transcripts_in_window(df, window, feature='gene'):
             gtable = df.loc[df["gene"] == g]
-            res.append(
-                Transcript(transcript=gtable["gene"].tolist()[0],
-                           gene=gtable["gene"].tolist()[0],
-                           exon_tuples=gtable.loc[:, ["begin", "end"]].sort_values("begin")
-                           .itertuples(index=False,
-                                       name=None),
-                           strand=gtable["strand"].tolist()[0])
-            )
+            if len(gtable):
+                res.append(
+                    Transcript(transcript=gtable["gene"].tolist()[0],
+                               gene=gtable["gene"].tolist()[0],
+                               exon_tuples=gtable.loc[:, ["begin", "end"]].sort_values("begin")
+                               .itertuples(index=False,
+                                           name=None),
+                               strand=gtable["strand"].tolist()[0])
+                )
         sys.stderr.write("Found {} genes in the region.\n".format(len(res)))
+        logging.info("Found {} genes in the region.\n".format(len(res)))
     else:
         res = []
         for t in transcripts_in_window(df, window, feature="transcript"):
@@ -101,6 +106,7 @@ def parse_gtf(gtff, window, simplify=False):
                            strand=tr["strand"].tolist()[0])
             )
         sys.stderr.write("Found {} transcripts in the region.\n".format(len(res)))
+        logging.info("Found {} transcripts in the region.\n".format(len(res)))
     assign_colors_to_genes(res)
     return res
 
@@ -110,3 +116,12 @@ def assign_colors_to_genes(transcripts):
     colordict = {g: c for g, c in zip(genes, plcolors * 100)}
     for t in transcripts:
         t.color = colordict[t.gene]
+
+
+def parse_bed(bed, window):
+    logging.info("Parsing BED file")
+    df = pd.read_csv(bed, sep="\t", names=['chromosome', 'begin', 'end', 'name', 'score'])
+    return df.loc[df['begin'].between(window.begin, window.end)
+                  | df['end'].between(window.begin, window.end)] \
+        .drop(columns=['chromosome', 'score']) \
+        .itertuples(index=False, name=None)
